@@ -69,6 +69,8 @@ def build(ctx: click.core.Context, build_name: str, source: List[str], max_days:
 
     if "/" in build_name or "%2f" in build_name.lower():
         sys.exit("--name must not contain a slash and an encoded slash")
+    if "%25" in build_name:
+        sys.exit("--name must not contain encoded % (%25)")
     if not no_commit_collection and len(commits) != 0:
         sys.exit("--no-commit-collection must be specified when --commit is used")
 
